aboutsummaryrefslogtreecommitdiffstats
path: root/Installer/makeNetscapeSignedJar-Unix.sh
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2001-04-10 18:37:03 +0000
committerSven Gothel <[email protected]>2001-04-10 18:37:03 +0000
commit99f156a9d9e86e6d835ad9791071b23335476330 (patch)
treeb721df1c22bfc67fc6425d7d8ab1e9b9d2249ad1 /Installer/makeNetscapeSignedJar-Unix.sh
parente26f0c3e0a6be0f5555c5daee164047f3793d626 (diff)
Diffstat (limited to 'Installer/makeNetscapeSignedJar-Unix.sh')
-rwxr-xr-xInstaller/makeNetscapeSignedJar-Unix.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/Installer/makeNetscapeSignedJar-Unix.sh b/Installer/makeNetscapeSignedJar-Unix.sh
index bc58a4b..0cad301 100755
--- a/Installer/makeNetscapeSignedJar-Unix.sh
+++ b/Installer/makeNetscapeSignedJar-Unix.sh
@@ -5,9 +5,9 @@
# The Netscape signing keys were created using the Netscape signtool
# utility, as follows:
# copy key3.db and cert7.db from one of the users directories.
-# signtool -d . -G GL4JInst207
+# signtool -d . -G GL4JInst271
# Enter the following information:
# certificate common name: GL4JInst207
# organization: GL4Java Development Team
# organization unit: GL4JInst
# state or province: NRW
@@ -27,7 +27,7 @@ javac -classpath ".:../capsapi_classes.zip" *.java
. versionundef.sh
rm -rf META-INF
-signtool -d . -e .class -k GL4JInst270 -Z GL4JInst_ns.jar -c9 --norecurse .
+signtool -d . -e .class -k GL4JInst271 -Z GL4JInst_ns.jar -c9 --norecurse .
rm -rf META-INF
rm -f key3.db cert7.db *.class
@@ -5,9 +5,9 @@
# Enter the following information:
-# certificate common name: GL4JInst207
+# certificate common name: GL4JInst271
# organization: GL4Java Development Team
# organization unit: GL4JInst